.. NepTrainKit documentation master file, created by
   sphinx-quickstart on Wed Dec  4 19:50:15 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

NepTrain documentation
=========================
Welcome to NepTrain – an advanced automation toolkit for training neuroevolution potential (NEP). Simplify your workflows with seamless integration of GPUMD, VASP, and NEP, offering features like perturbation, active learning, single-point energy calculations, and efficient potential training.


.. toctree::
   :maxdepth: 2
   :caption: Documentation:

   install    <install/index>
   command    <command/index>
   example    <example/index>



